package com.capitalware.ufm.action.objects;

import java.io.File;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the HttpGetFile action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class HttpGetFileObject extends UFMFileObject
{
   public String     url = null;
   public String     toFile = null;
   public String     toDir = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public HttpGetFileObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (url != null)
         url   = Tokens.replace(url, paClass.actionProperties);
      if (toFile != null)
         toFile = Tokens.replace(toFile, paClass.actionProperties);
      if (toDir != null)
         toDir  = Tokens.replace(toDir, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      /* Do we need to create the directory? */
      if (createDir)
      {
         if (!(new File(toDir).exists()))
         {
            if ((new File(toDir)).mkdirs())
               UFM.logger.info("Successfully created directory: " + toDir);
            else
               throw new IllegalArgumentException("Error: Cannot create directory: " + toDir);
         }
      }
      else if (!(new File(toDir).exists()))
         throw new IllegalArgumentException("Target directory '"+toDir+"' does not exit.");
     
      if (url == null)
         throw new IllegalArgumentException("Error: You must specify a URL for the HttpGetFile action.");

      if (toDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the HttpGetFile action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     URL                  = " + url);
      UFM.logger.info("     Target Directory     = " + toDir);
      UFM.logger.info("     Target File          = " + (toFile == null ? "":toFile));
      UFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (toDir != null )
         file = "<"+CWConstants.FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+toDir+"\">"+toFile+"</"+CWConstants.FILE_ELEMENT+">";
      else
         file = "<"+CWConstants.FILE_ELEMENT+">"+toFile+"</"+CWConstants.FILE_ELEMENT+">";
      
      al.add("<"+CWConstants.HTTP_GET_FILE_ELEMENT+" "+CWConstants.URL_ATTRIBUTE+"=\""+url+"\" "+CWConstants.CREATE_DIR_ATTRIBUTE+"=\""+createDir+">"+LINE_SEPARATOR);
      
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+CWConstants.HTTP_GET_FILE_ELEMENT+">"+LINE_SEPARATOR);

      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      if (toFile == null)
         s = CWConstants.HTTP_GET_FILE_ELEMENT+", "+labelName+", "+CWConstants.HTTP_GET_FILE_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", "+CWConstants.URL_ATTRIBUTE+"="+url+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+LINE_SEPARATOR;
      else
         s = CWConstants.HTTP_GET_FILE_ELEMENT+", "+labelName+", "+CWConstants.HTTP_GET_FILE_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", "+CWConstants.URL_ATTRIBUTE+"="+url+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+", "+CWConstants.TO_FILE_ATTRIBUTE+"="+toFile+LINE_SEPARATOR;

      return s;
   }
}
