package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the WriteText action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class WriteTextObject extends UFMFileObject
{
   public String     toFile = null;
   public String     toDir = null;
   public boolean    append = false;
   public String     text = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public WriteTextObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (toDir != null)
         toDir  = Tokens.replace(toDir, paClass.actionProperties);

      if (toFile != null)
         toFile  = Tokens.replace(toFile, paClass.actionProperties);

      if (text != null)
      {
         text = Tokens.replace(text, paClass.actionProperties);
         // Add a trailing CRLF / LF
         text += System.getProperty("line.separator");
      }
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (toDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the WriteText action.");

      checkAndCreateDirectory(createDir, toDir);

      if (toFile == null)
         throw new IllegalArgumentException("Error: You must specify a filename for the WriteText action.");

      if (text == null)
         throw new IllegalArgumentException("Error: You must specify a text for the WriteText action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Target Directory     = " + (toDir == null ? "":toDir));
      UFM.logger.info("     Target File          = " + toFile);
      UFM.logger.info("     Append               = " + append);
      UFM.logger.info("     Text                 = " + text);
      UFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      
      if (toDir == null)
         al.add("<"+CWConstants.WRITE_TEXT_ELEMENT+" "+CWConstants.TO_FILE_ATTRIBUTE+"=\""+toFile+"\">"+LINE_SEPARATOR);
      else
         al.add("<"+CWConstants.WRITE_TEXT_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\" "+CWConstants.TO_FILE_ATTRIBUTE+"\""+toFile+"\">"+LINE_SEPARATOR);
      
      al.add(text);
      al.add("</"+CWConstants.WRITE_TEXT_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
   
   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      if (toDir == null)
         s = CWConstants.WRITE_TEXT_ELEMENT+", "+labelName+", "+CWConstants.WRITE_TEXT_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", "+CWConstants.TO_FILE_ATTRIBUTE+"="+toFile+", "+CWConstants.APPEND_ATTRIBUTE+"="+append+", Text="+text+LINE_SEPARATOR;
      else
         s = CWConstants.WRITE_TEXT_ELEMENT+", "+labelName+", "+CWConstants.WRITE_TEXT_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+", "+CWConstants.TO_FILE_ATTRIBUTE+"="+toFile+", "+CWConstants.APPEND_ATTRIBUTE+"="+append+", Text="+text+LINE_SEPARATOR;

      return s;
   }
}
