package com.capitalware.ufm.actions;

import java.io.File;
import java.io.IOException;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.CopyObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the copy action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class CopyAction extends UFMAction
{
   private CopyObject   co;

   /**
    * The constructor
    * @param co
    */
   public CopyAction(CopyObject co)
   {
      super(co.actionName);
      this.co = co;
   }

   /**
    * Perform the copy work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      co.printValues();

      if (co.srcFilename.indexOf('*') != -1)
         exitCode = handleManyFile();
      else
         exitCode = handleOneFile();

      if (!co.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }

   /**
    * Copy a single file
    * @return exitCode
    */
   private int handleOneFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      String toFilename;
      
      if (co.toFile != null)
         toFilename = IO.getFileName(co.toFile);
      else
         toFilename = IO.getFileName(co.srcFilename);

      toPathAndFilename = IO.apendFileToPath(co.toDir, toFilename);

      toPathAndFilename = Tokens.replace(co.actionName, toPathAndFilename, IO.getFileName(co.srcFilename), 1, co.paClass.actionProperties);

      try
      {
         IO.copyFile(co.srcFilename, toPathAndFilename);
         co.fileCount++;
      }
      catch (UFMException e)
      {
         exitCode = 8;
      }

      return exitCode;
   }

   /**
    * Copy a many files
    * @return exitCode
    */
   private int handleManyFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      File[] fileList;
      
      try
      {
         fileList = IO.getFilteredFileList(co.srcFilename);
         
         for (int i=0; i < fileList.length; i++)
         {
            String toFilename;

            if (co.toFile == null)
               toFilename = fileList[i].getName();
            else
               toFilename = co.toFile;

            toPathAndFilename = IO.apendFileToPath(co.toDir, toFilename);

            toPathAndFilename = Tokens.replace(co.actionName, toPathAndFilename, fileList[i].getName(), i+1, co.paClass.actionProperties);

            try
            {
               IO.copyFile(fileList[i].toString(), toPathAndFilename);
               co.fileCount++;
            }
            catch (UFMException e)
            {
               exitCode = 8;
            }
         }
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }

      return exitCode;
   }
}
