package com.capitalware.ufm.actions;

import java.io.File;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.HttpGetFileObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the HttpGetFile action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class HttpGetFileAction extends UFMAction
{
   private HttpGetFileObject   hgfo;

   /**
    * The constructor
    * @param co
    */
   public HttpGetFileAction(HttpGetFileObject hgfo)
   {
      super(hgfo.actionName);
      this.hgfo = hgfo;
   }

   /**
    * Perform the HttpGetFile work.
    * @return exitCode
    */
   public int doWork()
   {
      int      exitCode = 0;
      boolean  flag = true;
      hgfo.printValues();

      String toPathAndFilename;
      String toFilename = hgfo.toFile;
      
      if ( !(hgfo.url.startsWith("http://")) &&
           !(hgfo.url.startsWith("https://")) )
         hgfo.url = "http://" + hgfo.url;

      if (toFilename == null)
      {
         int x = hgfo.url.lastIndexOf('/');
         if (x != -1)
            toFilename = hgfo.url.substring(x+1);
         else
            toFilename = hgfo.url;
      }

      /* Do we need to create the directory? */
      if (hgfo.createDir)
      {
         if (!(new File(hgfo.toDir).exists()))
         {
            if ((new File(hgfo.toDir)).mkdirs()) 
               UFM.logger.info("Successfully created directory: " + hgfo.toDir);
            else
            {
               UFM.logger.fatal("Cannot create directory: " + hgfo.toDir);
               exitCode = 8;
               flag = false;
            }
         }
      }
      
      if (flag)
      {
         toPathAndFilename = IO.apendFileToPath(hgfo.toDir, toFilename);
         toPathAndFilename = Tokens.replace(hgfo.actionName, toPathAndFilename, IO.getFileName(hgfo.url), 1, hgfo.paClass.actionProperties);
   
         try
         {
            IO.copyFileFromURL(hgfo.url, toPathAndFilename);
            hgfo.fileCount++;
         }
         catch (UFMException e)
         {
            exitCode = 8;
         }
      }

      if (!hgfo.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }
}
