package com.capitalware.ufm.actions;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.RemoveItemsObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the RemoveItems action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RemoveItemsAction extends UFMAction
{
   private RemoveItemsObject   rio;

   /**
    * The constructor
    * @param rio
    */
   public RemoveItemsAction(RemoveItemsObject rio)
   {
      super(rio.actionName);
      this.rio = rio;
   }

   /**
    * Perform the RemoveItems work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      rio.printValues();

      String toPathAndFilename;
      String toFilename;
      
      if (rio.toFile != null)
         toFilename = IO.getFileName(rio.toFile);
      else
         toFilename = IO.getFileName(rio.srcFilename);

      toPathAndFilename = IO.apendFileToPath(rio.toDir, toFilename);

      toPathAndFilename = Tokens.replace(rio.actionName, toPathAndFilename, IO.getFileName(rio.srcFilename), 1, rio.paClass.actionProperties);

      try
      {
         int removeCount = IO.removeItems(rio.srcFilename, rio.itemFilename, toPathAndFilename);
         
         UFM.logger.info("Successfully removed "+removeCount+" items from file: "+rio.srcFilename+ " to " + toPathAndFilename);
         
         rio.fileCount++;
      }
      catch (UFMException e)
      {
         exitCode = 8;
      }

      if (!rio.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }
}
