package com.capitalware.ufm.actions;

import java.io.IOException;

import com.ice.tar.Tar;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.TarObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.handlers.Tokens;

/**
 * This class will handle the Tar action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class TarAction extends UFMAction
{
   private TarObject to;

   /**
    * The constructor
    * @param sfo
    */
   public TarAction(TarObject to)
   {
      super(to.actionName);
      this.to = to;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename;
      to.printValues();
      
      toPathAndFilename = IO.apendFileToPath(to.toDir, to.toFile);
      toPathAndFilename = Tokens.replace(to.actionName, toPathAndFilename, IO.getFileName(to.srcFilename), 1, to.paClass.actionProperties);

      try
      {
         Tar.createTar(to.srcFilename , toPathAndFilename);
         to.fileCount++;

         UFM.logger.info("Successfully created archive '" + to.toFile + "' from '" + to.srcFilename + "'");
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      finally
      {
         if (!to.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
