package com.capitalware.ufm.actions;

import java.io.File;
import java.io.IOException;

import com.ice.tar.Tar;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.UnTarObject;
import com.capitalware.ufm.handlers.Tokens;

/**
 * This class will handle the UnTar action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class UnTarAction extends UFMAction
{
   private UnTarObject uto;

   /**
    * The constructor
    * @param uto
    */
   public UnTarAction(UnTarObject uto)
   {
      super(uto.actionName);
      this.uto = uto;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      uto.printValues();

      uto.tarFilename = Tokens.replace(uto.actionName, uto.tarFilename, uto.toDir, 1, uto.paClass.actionProperties);

      try
      {
         Tar.extractFiles(new File(uto.tarFilename), new File(uto.toDir));
         uto.fileCount++;

         UFM.logger.info("Successfully extracted archive '" + uto.tarFilename + "' to '" + uto.toDir + "'");
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      finally
      {
         if (!uto.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
