package com.capitalware.ufm.handlers;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.objects.UFMException;

public class CharacterConversion
{
   private static final char CARRIAGE_RETURN = '\r';  // Carriage Return
   private static final char NEW_LINE        = '\n';  // New Line (or Line Feed)
   
   private static final byte [] ASCII_EBCDIC_ARRAY = 
   {
      (byte)0x00,(byte)0x01,(byte)0x02,(byte)0x03,(byte)0x37,(byte)0x2D,(byte)0x2E,(byte)0x2F,
      (byte)0x16,(byte)0x05,(byte)0x25,(byte)0x0B,(byte)0x0C,(byte)0x0D,(byte)0x0E,(byte)0x0F,
      (byte)0x10,(byte)0x11,(byte)0x12,(byte)0x13,(byte)0x3C,(byte)0x3D,(byte)0x32,(byte)0x26,
      (byte)0x18,(byte)0x19,(byte)0x3F,(byte)0x27,(byte)0x22,(byte)0x1D,(byte)0x35,(byte)0x1F,
      (byte)0x40,(byte)0x5A,(byte)0x7F,(byte)0x7B,(byte)0x5B,(byte)0x6C,(byte)0x50,(byte)0x7D,
      (byte)0x4D,(byte)0x5D,(byte)0x5C,(byte)0x4E,(byte)0x6B,(byte)0x60,(byte)0x4B,(byte)0x61,
      (byte)0xF0,(byte)0xF1,(byte)0xF2,(byte)0xF3,(byte)0xF4,(byte)0xF5,(byte)0xF6,(byte)0xF7,
      (byte)0xF8,(byte)0xF9,(byte)0x7A,(byte)0x5E,(byte)0x4C,(byte)0x7E,(byte)0x6E,(byte)0x6F,
      (byte)0x7C,(byte)0xC1,(byte)0xC2,(byte)0xC3,(byte)0xC4,(byte)0xC5,(byte)0xC6,(byte)0xC7,
      (byte)0xC8,(byte)0xC9,(byte)0xD1,(byte)0xD2,(byte)0xD3,(byte)0xD4,(byte)0xD5,(byte)0xD6,
      (byte)0xD7,(byte)0xD8,(byte)0xD9,(byte)0xE2,(byte)0xE3,(byte)0xE4,(byte)0xE5,(byte)0xE6,
      (byte)0xE7,(byte)0xE8,(byte)0xE9,(byte)0xAD,(byte)0xE0,(byte)0xBD,(byte)0x5F,(byte)0x6D,
      (byte)0x79,(byte)0x81,(byte)0x82,(byte)0x83,(byte)0x84,(byte)0x85,(byte)0x86,(byte)0x87,
      (byte)0x88,(byte)0x89,(byte)0x91,(byte)0x92,(byte)0x93,(byte)0x94,(byte)0x95,(byte)0x96,
      (byte)0x97,(byte)0x98,(byte)0x99,(byte)0xA2,(byte)0xA3,(byte)0xA4,(byte)0xA5,(byte)0xA6,
      (byte)0xA7,(byte)0xA8,(byte)0xA9,(byte)0xC0,(byte)0x6A,(byte)0xD0,(byte)0xA1,(byte)0x07,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,
      (byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00,(byte)0x00
   };
                                                                                             
   private static final byte [] EBCDIC_ASCII_ARRAY = 
   {
      (byte)0X00, (byte)0X01, (byte)0X02, (byte)0X03, (byte)0X00, (byte)0X09, (byte)0X00, (byte)0X7F,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X0B, (byte)0X0C, (byte)0X0D, (byte)0X0E, (byte)0X0F,
      (byte)0X10, (byte)0X11, (byte)0X12, (byte)0X13, (byte)0X00, (byte)0X0A, (byte)0X08, (byte)0X00,
      (byte)0X18, (byte)0X19, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X0A, (byte)0X17, (byte)0X1B,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X05, (byte)0X06, (byte)0X07,
      (byte)0X00, (byte)0X00, (byte)0X16, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X04,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X15, (byte)0X00, (byte)0X1A,
      (byte)0X20, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X2E, (byte)0X3C, (byte)0X28, (byte)0X2B, (byte)0X7C,
      (byte)0X26, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X21, (byte)0X24, (byte)0X2A, (byte)0X29, (byte)0X3B, (byte)0X00,
      (byte)0X2D, (byte)0X2F, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X2C, (byte)0X25, (byte)0X5F, (byte)0X3E, (byte)0X3F,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X60, (byte)0X3A, (byte)0X23, (byte)0X40, (byte)0X27, (byte)0X3D, (byte)0X22,
      (byte)0X00, (byte)0X61, (byte)0X62, (byte)0X63, (byte)0X64, (byte)0X65, (byte)0X66, (byte)0X67,
      (byte)0X68, (byte)0X69, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X6A, (byte)0X6B, (byte)0X6C, (byte)0X6D, (byte)0X6E, (byte)0X6F, (byte)0X70,
      (byte)0X71, (byte)0X72, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X7E, (byte)0X73, (byte)0X74, (byte)0X75, (byte)0X76, (byte)0X77, (byte)0X78,
      (byte)0X79, (byte)0X7A, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X5B, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X5D, (byte)0X00, (byte)0X00,
      (byte)0X7B, (byte)0X41, (byte)0X42, (byte)0X43, (byte)0X44, (byte)0X45, (byte)0X46, (byte)0X47,
      (byte)0X48, (byte)0X49, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X7D, (byte)0X4A, (byte)0X4B, (byte)0X4C, (byte)0X4D, (byte)0X4E, (byte)0X4F, (byte)0X50,
      (byte)0X51, (byte)0X52, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X5C, (byte)0X00, (byte)0X53, (byte)0X54, (byte)0X55, (byte)0X56, (byte)0X57, (byte)0X58,
      (byte)0X59, (byte)0X5A, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00,
      (byte)0X30, (byte)0X31, (byte)0X32, (byte)0X33, (byte)0X34, (byte)0X35, (byte)0X36, (byte)0X37,
      (byte)0X38, (byte)0X39, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00, (byte)0X00
   };

   /**
    * The constructor - make sure nothing instantiates this class.
    * It must be accessed in a static way.
    */
   private CharacterConversion()
   {}

   /**
    * DOS to EBCDIC character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void dos2Ebcdic(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      int last = -1;
      boolean failed = false;
      UFM.logger.debug("dos2Ebcdic(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == CARRIAGE_RETURN)
            {
               // skip it for now
            }
            else if ((last == CARRIAGE_RETURN) && (c == NEW_LINE))
            {
               out.write(ASCII_EBCDIC_ARRAY[NEW_LINE]);  // only write out \n only
            }
            else if ((last == CARRIAGE_RETURN) && (c != NEW_LINE))
            {
               out.write(ASCII_EBCDIC_ARRAY[last]);  // write out \r and
               out.write(ASCII_EBCDIC_ARRAY[c]);     // write out this char
            }
            else
               out.write(ASCII_EBCDIC_ARRAY[c]);     // write out this char

            last = c;
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("dos2Ebcdic had an error. Please check log for more details.");
   }

   /**
    * DOS to Mac OS X character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void dos2Mac(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      int last = -1;
      boolean failed = false;
      UFM.logger.debug("dos2Mac(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if ((last == CARRIAGE_RETURN) && (c == NEW_LINE))
            {
               // skip \n
            }
            else
               out.write(c);     // write out this char

            last = c;
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("dos2Mac had an error. Please check log for more details.");
   }

   /**
    * DOS to Unix character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void dos2Unix(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      int last = -1;
      boolean failed = false;
      UFM.logger.debug("dos2Unix(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == CARRIAGE_RETURN)
            {
               // skip it for now
            }
            else if ((last == CARRIAGE_RETURN) && (c == NEW_LINE))
            {
               out.write(NEW_LINE);  // only write out \n
            }
            else if ((last == CARRIAGE_RETURN) && (c != NEW_LINE))
            {
               out.write(last);  // write out \r and
               out.write(c);     // write out this char
            }
            else
               out.write(c);     // write out this char

            last = c;
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("dos2Unix had an error. Please check log for more details.");
   }

   /**
    * EBCDIC to DOS (Windows) character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void ebcdic2Dos(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      int t;
      boolean failed = false;
      UFM.logger.debug("ebcdic2Dos(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            t = EBCDIC_ASCII_ARRAY[c];
            
            if (t == NEW_LINE)
            {
               out.write(CARRIAGE_RETURN);  // write out \r and
               out.write(NEW_LINE);         // write out \n and
            }
            else
               out.write(t);                // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("ebcdic2Dos had an error. Please check log for more details.");
   }

   /**
    * EBCDIC to Mac OS X character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void ebcdic2Mac(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      int t;
      boolean failed = false;
      UFM.logger.debug("ebcdic2Mac(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            t = EBCDIC_ASCII_ARRAY[c];
            
            if (t == NEW_LINE)
            {
               out.write(CARRIAGE_RETURN);  // write out \r and
            }
            else
               out.write(t);                // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("ebcdic2Mac had an error. Please check log for more details.");
   }

   /**
    * EBCDIC to Unix character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void ebcdic2Unix(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("ebcdic2Unix(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            out.write(EBCDIC_ASCII_ARRAY[c]);
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("ebcdic2Unix had an error. Please check log for more details.");
   }

   /**
    * Mac OS X to DOS (Windows) character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void mac2Dos(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("mac2Dos(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == CARRIAGE_RETURN)
            {
               out.write(CARRIAGE_RETURN);  // write out \r and
               out.write(NEW_LINE);         // write out \n and
            }
            else
               out.write(c);                // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("mac2Dos had an error. Please check log for more details.");
   }

   /**
    * Mac OS X to EBCDIC character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void mac2Ebcdic(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("mac2Ebcdic(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == CARRIAGE_RETURN)
               out.write(ASCII_EBCDIC_ARRAY[NEW_LINE]);  // only write out \n
            else
               out.write(ASCII_EBCDIC_ARRAY[c]);         // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("mac2Ebcdic had an error. Please check log for more details.");
   }

   /**
    * Mac OS X to Unix character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void mac2Unix(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("mac2Unix(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == CARRIAGE_RETURN)
               out.write(NEW_LINE);  // only write out \n
            else
               out.write(c);         // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("mac2Unix had an error. Please check log for more details.");
   }

   /**
    * Unix to DOS (Windows) character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void unix2Dos(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("unix2Dos(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == NEW_LINE)
            {
               out.write(CARRIAGE_RETURN);  // write out \r and
               out.write(NEW_LINE);         // write out \n and
            }
            else
               out.write(c);                // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("unix2Dos had an error. Please check log for more details.");
   }

   /**
    * Unix to EBCDIC character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void unix2Ebcdic(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("unix2Ebcdic(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            out.write(ASCII_EBCDIC_ARRAY[c]);         // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("unix2Ebcdic had an error. Please check log for more details.");
   }

   /**
    * Unix to Mac OS X character conversion.
    * @param srcPathAndFile
    * @param tgtPathAndFile
    * @throws UFMException
    */
   public static void unix2Mac(String srcPathAndFile, String tgtPathAndFile) throws UFMException
   {
      File srcFile = new File(srcPathAndFile);
      File tgtFile = new File(tgtPathAndFile);
      BufferedReader in = null;
      BufferedWriter out = null;
      int c;
      boolean failed = false;
      UFM.logger.debug("unix2Mac(): '" + srcPathAndFile + "' : '"+tgtPathAndFile+"'");

      try
      {
         in = new BufferedReader(new FileReader(srcFile));
         out = new BufferedWriter(new FileWriter(tgtFile));

         while ((c = in.read()) != -1)
         {
            if (c == NEW_LINE)
               out.write(CARRIAGE_RETURN); // only write out \r
            else
               out.write(c);     // write out this char
         }
         out.flush();
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         failed = true;
      }
      finally
      {
         try
         {
            if (in != null)
               in.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
         try
         {
            if (out != null)
               out.close();
         }
         catch (IOException e)
         {
            UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            failed = true;
         }
      }
      
      if (failed == true)
         throw new UFMException("unix2Mac had an error. Please check log for more details.");
   }
}
