package com.capitalware.ufm.handlers;

import java.io.*;
import java.util.*;

/**
 * This Class implements the FileFilter interface and can be used in a general
 * purpose way, when using a File objects listFiles(FileFilter) method to
 * display only files according to certain extension, including or excluding
 * directories.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class DirectoryWatchFilter implements FileFilter
{
   private HashMap<String,String> extHM;
   private boolean acceptAll = false;
   private boolean acceptDirs = false;

   /**
    * @param extensions
    *           Array of String containing Extensions of files to be accepted
    * @param acceptDirs
    *           set to true if "files" that are in fact directories should be
    *           accepted
    */
   public DirectoryWatchFilter(String[] extensions, boolean acceptDirs)
   {
      this.acceptDirs = acceptDirs;
      extHM = new HashMap<String,String>(extensions.length + 1);
      for (int i = 0; i < extensions.length; i++)
      {
         String s = extensions[i].toLowerCase();
         extHM.put(s, s);
         if (s.equalsIgnoreCase("*"))
            acceptAll = true;
      }
   }

   /**
    * Comment: acceptDirs is set to false by default.
    *
    * @param extensions
    *           Array of String containig Extensions of files to be accepted
    */
   public DirectoryWatchFilter(String[] extensions)
   {
      this(extensions, false);
   }

   /**
    * Extract extension from filename
    *
    * @param f
    *           File object
    */
   private String getExtension(File f)
   {
      String name = f.getName();
      String extension = "";
      int i = name.lastIndexOf(".");
      if (i > 0)
         extension = name.substring(i + 1);
      return extension.toLowerCase();
   }

   /**
    * @returns true if file is of correct filetype, false if it is of wrong
    *          filetype
    */
   public boolean accept(File f)
   {
      boolean doAccept = acceptAll;
      if (!doAccept)
      {
         if (extHM.get(getExtension(f)) != null)
            doAccept = true;
      }
      if (f.isDirectory())
         doAccept = acceptDirs;
      return doAccept;
   }

}