package com.capitalware.ufm.objects;

import java.io.File;

import com.ibm.mq.constants.CMQC;

/**
 * This class holds the constant values.
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.0
 * @license Apache 2 License
 */
public class CWConstants
{
   /**
    * The constructor - make sure nothing instantiates this class.
    * It must be accessed in a static way.
    */
   private CWConstants()
   {}

   public static final String    VERSION                 = "2.0.0.1";

   public static final String    XML_SUFFIX              = ".xml";
   public static final String    HOME_PATH               = System.getProperty("user.dir") + File.separator + "data" + File.separator;
   public static final String    ARCHIVE_PATH            = System.getProperty("user.dir") + File.separator + "archive" + File.separator;
   public static final String    EMAIL_PATH              = System.getProperty("user.dir") + File.separator + "email" + File.separator;
   public static final String    FTP_PATH                = System.getProperty("user.dir") + File.separator + "ftp" + File.separator;
   public static final String    JOBS_PATH               = System.getProperty("user.dir") + File.separator + "jobs" + File.separator;
   public static final String    MQ_PATH                 = System.getProperty("user.dir") + File.separator + "mq" + File.separator;
   public static final String    SCHEDULE_PATH           = System.getProperty("user.dir") + File.separator + "schedule" + File.separator;
   public static final String    SCP_PATH                = System.getProperty("user.dir") + File.separator + "scp" + File.separator;
   public static final String    SFTP_PATH               = System.getProperty("user.dir") + File.separator + "sftp" + File.separator;

   public static final String    WORKFLOW_DTD            = "UFM_Workflow.dtd";
   public static final String    EMAIL_DTD               = "UFM_Email_SMTP.dtd";
   public static final String    FTP_DTD                 = "UFM_Ftp.dtd";
   public static final String    HOLIDAY_DTD             = "UFM_Holiday.dtd";
   public static final String    JOBS_DTD                = "UFM_Job.dtd";
   public static final String    MQ_DTD                  = "UFM_MQ.dtd";
   public static final String    SCHEDULE_DTD            = "UFM_Schedule.dtd";
   public static final String    SCP_DTD                 = "UFM_Scp.dtd";
   public static final String    SFTP_DTD                = "UFM_SFtp.dtd";

   public static final String    LOG4J_APPENDER_UFM      = "ufm";
   
   public static final String    SERVICE_FILE_NAME       = "service.properties";

   public static final String    QUIT_MSG                = "QUIT";

   public static final int       MAX_GROUP_MSG_SIZE      = 4190000;   // 4MB - 4304

   public static final String    HOSTNAME_TOKEN          = "${HOSTNAME}";
   public static final String    IPADDRESS_TOKEN         = "${IPADDRESS}";
   public static final String    WATCH_FOUND_FILE        = "${WATCH_FOUND_FILE}";
   public static final String    LOOP_COUNTER            = "${LOOP_COUNTER}";
   public static final String    MQ_RECEIVE_FILE         = "${MQ_RECEIVE_FILE}";
   public static final String    MQ_REPLY_TO_QMGR_NAME   = "${MQ_REPLY_TO_QMGR_NAME}";
   public static final String    MQ_REPLY_TO_QUEUE_NAME  = "${MQ_REPLY_TO_QUEUE_NAME}";

   public static final int       MQTMC_V1_LENGTH         = 684;
   public static final int       MQTMC_V2_LENGTH         = 732;

   public static final int       TIME_TO_LIVE_DEFAULT    = 7;  // 7 days

   /**
    * Flag to determine how to run Receive action
    */
   public static final char      ONE_PASS          = 'S';  // single
   public static final char      RUN_UNTIL_EMPTY   = 'E';  // empty
   public static final char      TRIGGERED         = 'T';  // triggered
   public static final char      DAEMON            = 'D';  // Unix daemon or Windows service

   /**
    * General flags
    */
   public static final char      YES_FLAG          = 'Y';

   /**
    * ftp & sftp flags 
    */
   public static final char      FTP_MODE_ASCII    = 'A';
   public static final char      FTP_MODE_BINARY   = 'I';
   
   /**
    * Ports for ftp, sftp, scp
    */
   public static final int       FTP_DEFAULT_PORT  = 21;
   public static final int       SCP_DEFAULT_PORT  = 22;
   public static final int       SFTP_DEFAULT_PORT = 22;
   
   /**
    * Flag for the format of the message
    */
   public static final char      FORMAT_STRING     = 'S';
   public static final char      FORMAT_ZIP        = 'Z';
   /**
    * Flags for file splitting
    */
   public static final char      SPLIT_MODE_BINARY = 'B';
   public static final char      SPLIT_MODE_LINE   = 'L';
   
   /**
    * The marker is the high order 16 bits i.e.  x'0011 0000'
    * The lower 16-bits are used as a flag.
    */
   public  final static int UFM_MSG = CMQC.MQFB_APPL_FIRST + 1048576;
   /*
    * Low order 16-bits.  This means we can have up to 16 flags.
    */
   public  final static int UFM_ZIP_MSG           = UFM_MSG + 1;     //  bit 0000 0000 0000 0001
   public  final static int UFM_START_JOB         = UFM_MSG + 2;     //  bit 0000 0000 0000 0010
   public  final static int UFM_XML_EMBEDDED_MSG  = UFM_MSG + 4;     //  bit 0000 0000 0000 0100
   public  final static int UFM_ENCRYPT_MSG       = UFM_MSG + 8;     //  bit 0000 0000 0000 1000
   public  final static int UFM_ZIP_ENCRYPT_MSG   = UFM_MSG + 9;     //  bit 0000 0000 0000 1001
   public  final static int UFM_V7_PROPERTIES_MSG = UFM_MSG + 16;    //  bit 0000 0000 0001 0000
   public  final static int UFM_STATUS_MSG        = UFM_MSG + 32768; //  bit 1000 0000 0000 0000 
   
   /**
    * Conversion flags
    */
   public  final static int   CONVERT_NONE         = -1;
   public  final static int   CONVERT_DOS_2_EBCDIC = 0;
   public  final static int   CONVERT_DOS_2_MAC    = 1;
   public  final static int   CONVERT_DOS_2_UNIX   = 2;
   public  final static int   CONVERT_EBCDIC_2_DOS = 3;
   public  final static int   CONVERT_EBCDIC_2_MAC = 4;
   public  final static int   CONVERT_EBCDIC_2_UNIX= 5;
   public  final static int   CONVERT_MAC_2_DOS    = 6;
   public  final static int   CONVERT_MAC_2_EBCDIC = 7;
   public  final static int   CONVERT_MAC_2_UNIX   = 8;
   public  final static int   CONVERT_UNIX_2_DOS   = 9;
   public  final static int   CONVERT_UNIX_2_EBCDIC= 10;
   public  final static int   CONVERT_UNIX_2_MAC   = 11;
   
   public  final static String[] CONVERT_ARRAY = 
   {
     "D2E", "D2M", "D2U",  /* DOS */
     "E2D", "E2M", "E2U",  /* EBCDIC */
     "M2D", "M2E", "M2U",  /* Mac OS X */
     "U2D", "U2E", "U2M"   /* Unix/Linux */
   };

   /**
    * XML related elements and attributes
    */
   public static final String XML_PROLOG              = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><!DOCTYPE UFM_Msg>";
   public static final String UFM_MSG_ELEMENT        = "UFM_Msg";
   /**
    * UFM Major Elements
    */
   public static final String GLOBAL_ELEMENT          = "Global";
   public static final String ACTIONS_ELEMENT         = "Actions";
   /**
    * Global Elements
    */
   public static final String PROPERTY_ELEMENT        = "Property";
   public static final String STATUS_ELEMENT          = "Status";
   public static final String LOG_FILE_ELEMENT        = "LogFile";
   public static final String LOG4J_PROP_FILE_ELEMENT = "Log4JFile";
   public static final String ON_ERROR_ELEMENT        = "OnError";
   /**
    * Action elements
    */
   public static final String APPEND_ELEMENT          = "Append";
   public static final String CONVERT_ELEMENT         = "Convert";
   public static final String COPY_ELEMENT            = "Copy";
   public static final String DECRYPT_FILE_ELEMENT    = "DecryptFile";
   public static final String DELETE_ELEMENT          = "Delete";
   public static final String ECHO_ELEMENT            = "Echo";
   public static final String ENCRYPT_FILE_ELEMENT    = "EncryptFile";
   public static final String EXECUTE_ELEMENT         = "Execute";
   public static final String FTP_ELEMENT             = "Ftp";
   public static final String HOLIDAY_ELEMENT         = "Holiday";
   public static final String HTTP_GET_FILE_ELEMENT   = "HttpGetFile";
   public static final String HTTP_PUT_FILE_ELEMENT   = "HttpPutFile";
   public static final String IF_ELEMENT              = "If";
   public static final String ELSE_ELEMENT            = "Else";
   public static final String LAUNCH_ELEMENT          = "Launch";
   public static final String LOOP_ELEMENT            = "Loop";
   public static final String MAKEDIR_ELEMENT         = "MakeDir";
   public static final String MERGE_ELEMENT           = "Merge";
   public static final String MERGE_SORT_ELEMENT      = "MergeSort";
   public static final String MOVE_ELEMENT            = "Move";
   public static final String MQ_PUTQUIT_ELEMENT      = "MQPutQuit";
   public static final String MQ_RECEIVE_ELEMENT      = "MQReceive";
   public static final String MQ_SEND_ELEMENT         = "MQSend";
   public static final String REENCODE_ELEMENT        = "ReEncode";
   public static final String REMOVE_ITEMS_ELEMENT    = "RemoveItems";
   public static final String REMOVE_DIR_ELEMENT      = "RemoveDir";
   public static final String RENAME_ELEMENT          = "Rename";
   public static final String REPLACE_TEXT_ELEMENT    = "ReplaceText";
   public static final String SCHEDULE_ELEMENT        = "Schedule";
   public static final String SCP_ELEMENT             = "Scp";
   public static final String SEND_EMAIL_ELEMENT      = "SendEmail";
   public static final String SFTP_ELEMENT            = "SFtp";
   public static final String SLEEP_ELEMENT           = "Sleep";
   public static final String SORT_ELEMENT            = "Sort";
   public static final String SORT_UNIQUE_ELEMENT     = "SortUnique";
   public static final String SPLIT_ELEMENT           = "Split";
   public static final String TAR_ELEMENT             = "Tar";
   public static final String TOUCH_ELEMENT           = "Touch";
   public static final String UNIQUE_ELEMENT          = "Unique";
   public static final String UNTAR_ELEMENT           = "UnTar";
   public static final String UNZIP_ELEMENT           = "UnZip";
   public static final String WATCH_ELEMENT           = "Watch";
   public static final String WRITE_TEXT_ELEMENT      = "WriteText";
   public static final String ZIP_ELEMENT             = "Zip";
   /**
    * MQ Elements
    */
   public static final String MQ_ELEMENT                 = "MQ";
   public static final String MQFILE_ELEMENT             = "MQFile";
   public static final String CCDTFILE_ELEMENT           = "CCDTFile";
   public static final String CORREL_ID_ELEMENT          = "CorrelId";
   public static final String QMGRNAME_ELEMENT           = "QMgrName";
   public static final String QUEUENAME_ELEMENT          = "QueueName";
   public static final String DISTRIBUTIONLIST_ELEMENT   = "DistributionList";
   //
   public static final String CHANNELNAME_ELEMENT        = "ChannelName";
   public static final String SECURITYEXIT_ELEMENT       = "SecurityExit";
   public static final String SECURITYEXITPATH_ELEMENT   = "SecurityExitPath";
   public static final String SECURITYEXITDATA_ELEMENT   = "SecurityExitData";
   public static final String CIPHERSUITENAME_ELEMENT    = "CipherSuiteName";
   public static final String DISTINGUISHEDNAME_ELEMENT  = "DistinguishedName";
   public static final String TRUSTEDSTORE_ELEMENT       = "TrustedStore";
   public static final String TRUSTEDSTOREPASSWD_ELEMENT = "TrustedStorePasswd";
   public static final String KEYSTORE_ELEMENT           = "KeyStore";
   public static final String KEYSTOREPASSWD_ELEMENT     = "KeyStorePasswd";
   public static final String LDAPSERVER_ELEMENT         = "LDAPServer";
   public static final String LDAPSERVERPORT_ELEMENT     = "LDAPServerPort";

   public static final String BACKOUTQNAME_ELEMENT       = "BackOutQName";
   public static final String REPLYTOQNAME_ELEMENT       = "ReplyToQName";
   public static final String STATUSQNAME_ELEMENT        = "StatusQName";
   /**
    * General Elements
    */
   public static final String FILE_ELEMENT            = "File";
   public static final String ARCHIVE_ELEMENT         = "Archive";
   public static final String REMOTE_ELEMENT          = "Remote";
   public static final String DIRECTORY_ELEMENT       = "Directory";
   public static final String DEFAULT_ELEMENT         = "Default";
   public static final String FILENAME_ELEMENT        = "FileName";
   
   /**
    * Common elements to RemoveItems 
    */
   public static final String ITEM_FILE_ELEMENT       = "ItemFile";
   /**
    * Common elements to MQ, SMTP, ftp, sftp 
    */
   public static final String HOSTNAME_ELEMENT        = "Hostname";
   public static final String PORT_ELEMENT            = "Port";
   public static final String USERID_ELEMENT          = "UserID";
   public static final String PASSWORD_ELEMENT        = "Password";
   /**
    * Job Elements
    */
   public static final String JOB_ELEMENT             = "Job";
   public static final String COMMAND_ELEMENT         = "Command";
   public static final String PARM_ELEMENT            = "Parm";
   /**
    * SMTP Email Elements
    */
   public static final String FROM_EMAIL_ELEMENT      = "FromEmailAddress";
   public static final String TO_EMAIL_ELEMENT        = "ToEmailAddress";
   public static final String EMAIL_SUBJECT_ELEMENT   = "Subject";
   public static final String EMAIL_MSG_TEXT_ELEMENT  = "MessageText";
   /**
    * FTP / SFTP
    */
   public static final String FTP_CMDS_ELEMENT        = "FtpCmds";
   public static final String SFTP_CMDS_ELEMENT       = "SFtpCmds";

   public static final String FTP_GET_ELEMENT         = "Get";
   public static final String FTP_PUT_ELEMENT         = "Put";
   public static final String FTP_CD_ELEMENT          = "Cd";
   public static final String FTP_TYPE_ELEMENT        = "Type";
   public static final String FTP_MKDIR_ELEMENT       = "MkDir";
   public static final String FTP_RMDIR_ELEMENT       = "RmDir";
   public static final String FTP_DELETE_ELEMENT      = "Delete";
   /**
    * SCP
    */
   public static final String SCP_CMDS_ELEMENT        = "ScpCmds";
   public static final String SCP_COPY_TO_ELEMENT     = "CopyTo";
   public static final String SCP_COPY_FROM_ELEMENT   = "CopyFrom";
   /**
    * Watch Elements
    */
   public static final String WATCH_ITEM_ELEMENT      = "WatchItem";
   public static final String EXTENSION_ELEMENT       = "Extension";
   /**
    * Schedule Elements
    */
   public static final String MINUTE_ELEMENT          = "Minute";
   public static final String HOUR_ELEMENT            = "Hour";
   public static final String DAYOFMONTH_ELEMENT      = "DayOfMonth";
   public static final String MONTH_ELEMENT           = "Month";
   public static final String DAYOFWEEK_ELEMENT       = "DayOfWeek";
   public static final String YEAR_ELEMENT            = "Year";
   public static final String HOLIDAY_FILE_ELEMENT    = "HolidayFile";
   // Holiday Elements
   public static final String DAY_ELEMENT             = "Day";
   /**
    * ReplaceText Elements
    */
   public static final String FIND_ELEMENT            = "Find";
   public static final String REPLACE_ELEMENT         = "Replace";
   /**
    * Attributes
    */
   public static final String ACTION_NAME_ATTRIBUTE   = "actionname";
   public static final String APPEND_ATTRIBUTE        = "append";
   public static final String AUTHENTICATION_ATTRIBUTE= "authentication";
   public static final String BY_ATTRIBUTE            = "by";
   public static final String COLUMN_ATTRIBUTE        = "column";
   public static final String COLUMNS_ATTRIBUTE       = "columns";
   public static final String CREATE_DIR_ATTRIBUTE    = "createdir";
   public static final String DELETE_ATTRIBUTE        = "delete";
   public static final String DIR_ATTRIBUTE           = "dir";
   public static final String END_ATTRIBUTE           = "end";
   public static final String EXIT_RC_ATTRIBUTE       = "exitrc";
   public static final String EXTENSION_ATTRIBUTE     = "extension";
   public static final String FIELD_NAME_ATTRIBUTE    = "fieldname";
   public static final String FORM_DATA_NAME_ATTRIBUTE= "form-data-name";
   public static final String FORMAT_ATTRIBUTE        = "format";
   public static final String GETWITHCONVERT_ATTRIBUTE= "getwithconvert";
   public static final String HOURS_ATTRIBUTE         = "hours";
   public static final String IF_EXIST_DIR_ATTRIBUTE  = "ifexistfail";
   public static final String INPUT_ENCODING_ATTRIBUTE= "inputencoding";
   public static final String KEY_SIZE_ATTRIBUTE      = "keysize";
   public static final String LABEL_ATTRIBUTE         = "label";
   public static final String LABEL_NAME_ATTRIBUTE    = "labelname";
   public static final String MILLISECONDS_ATTRIBUTE  = "milliseconds";
   public static final String MINUTES_ATTRIBUTE       = "minutes";
   public static final String MODE_ATTRIBUTE          = "mode";
   public static final String NAME_ATTRIBUTE          = "name";
   public static final String ON_ERROR_FAIL_ATTRIBUTE = "onerrorfail";
   public static final String OPERATOR_ATTRIBUTE      = "operator";
   public static final String ORDER_ATTRIBUTE         = "order";
   public static final String OUTPUT_ENCODING_ATTRIBUTE= "outputencoding";
   public static final String OVERRIDE_ATTRIBUTE      = "override";
   public static final String PASS_PHRASE_ATTRIBUTE   = "passphrase";
   public static final String PERSISTENCE_ATTRIBUTE   = "persistence";
   public static final String CCSID_ATTRIBUTE         = "ccsid";
   public static final String POLL_INTERVAL_ATTRIBUTE = "pollinterval";
   public static final String PREFIX_ATTRIBUTE        = "prefix";
   public static final String PRIORITY_ATTRIBUTE      = "priority";
   public static final String QMGRNAME_ATTRIBUTE      = "qmgrname";
   public static final String REMOTE_DIR_ATTRIBUTE    = "remotedir";
   public static final String REMOTE_FILE_ATTRIBUTE   = "remotefile";
   public static final String REMOVE_ALL_ATTRIBUTE    = "removeall";
   public static final String ROWS_ATTRIBUTE          = "rows";
   public static final String RUN_ATTRIBUTE           = "run";
   public static final String SECONDS_ATTRIBUTE       = "seconds";
   public static final String SEND_ON_STARTUP         = "sendonstartup";
   public static final String SIZE_ATTRIBUTE          = "size";
   public static final String SSL_ATTRIBUTE           = "ssl";
   public static final String START_ATTRIBUTE         = "start";
   public static final String TIME_TO_LIVE_ATTRIBUTE  = "timetolive";
   public static final String TO_DIR_ATTRIBUTE        = "todir";
   public static final String TO_FILE_ATTRIBUTE       = "tofile";
   public static final String TYPE_ATTRIBUTE          = "type";
   public static final String URL_ATTRIBUTE           = "url";
   public static final String USE_FILE_LOCKING        = "usefilelocking";   
   public static final String USE_V7_PROPERTIES       = "usev7prop";
   public static final String VALUE_ATTRIBUTE         = "value";
   public static final String WAIT_ATTRIBUTE          = "wait";
   public static final String XML_FILE_ATTRIBUTE      = "xmlfile";

   /*
    * V7 Properties
    */
   public static final String UFM_PROP_DIRECTORY      = "UFM_Directory";
   public static final String UFM_PROP_FILENAME       = "UFM_FileName";
   public static final String UFM_PROP_EXECUTE        = "UFM_Excute";
   
   /**
    * Different alerts for 3rd party central management systems
    */
   public static final int       ALERT_SUCCESS              = 1;
   public static final int       ALERT_INFO                 = 2;
   public static final int       ALERT_DEBUG                = 3;
   public static final int       ALERT_ERROR                = 4;
   public static final int       ALERT_FATAL                = 5;
   public static final int       ALERT_INVALID_PARAMETERS   = 6;
   public static final int       ALERT_UKNOWN_ACTION        = 7;
   public static final int       ALERT_JDOM                 = 8;
   public static final int       ALERT_IO                   = 9;
   public static final int       ALERT_UNSATISFIED_LINK     = 10;
   public static final int       ALERT_STARTING             = 11;
   public static final int       ALERT_TERMINATING          = 12;
   public static final int       ALERT_EAMIL                = 13;
   public static final int       ALERT_MQ                   = 14;
   public static final int       ALERT_FTP                  = 15;
   public static final int       ALERT_HTTP                 = 16;
   public static final int       ALERT_SCP                  = 17;
   public static final int       ALERT_SFTP                 = 18;
}
